@@ -1,6 +1,6 @@
 /* deflate.c -- compress data using the deflation algorithm
 
-   Copyright (C) 1999, 2006, 2009-2018 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2006, 2009-2023 Free Software Foundation, Inc.
    Copyright (C) 1992-1993 Jean-loup Gailly
 
    This program is free software; you can redistribute it and/or modify
@@ -68,7 +68,7 @@
  *      void lm_init (int pack_level, ush *flags)
  *          Initialize the "longest match" routines for a new file
  *
- *      off_t deflate (void)
+ *      off_t deflate ()
  *          Processes a new input file and return its compressed length. Sets
  *          the compressed length, crc, deflate flags and internal file
  *          attributes.
@@ -123,10 +123,6 @@
 #define NIL 0
 /* Tail of hash chains */
 
-#define FAST 4
-#define SLOW 2
-/* speed options for the general purpose bit flag */
-
 #ifndef TOO_FAR
 #  define TOO_FAR 4096
 #endif
@@ -180,7 +176,7 @@ long block_start;
  * negative when the window is moved backwards.
  */
 
-local unsigned ins_h;  /* hash index of string to be inserted */
+static unsigned ins_h;  /* hash index of string to be inserted */
 
 #define H_SHIFT  ((HASH_BITS+MIN_MATCH-1)/MIN_MATCH)
 /* Number of bits by which ins_h and del_h must be shifted at each
@@ -196,15 +192,15 @@ local unsigned ins_h;  /* hash index of string to be inserted */
 
       unsigned near strstart;      /* start of string to insert */
       unsigned near match_start;   /* start of matching string */
-local int           eofile;        /* flag set at end of input file */
-local unsigned      lookahead;     /* number of valid bytes ahead in window */
+static int eofile;		   /* flag set at end of input file */
+static unsigned lookahead;	   /* number of valid bytes ahead in window */
 
        unsigned max_chain_length;
 /* To speed up deflation, hash chains are never searched beyond this length.
  * A higher limit improves compression ratio but degrades the speed.
  */
 
-local unsigned int max_lazy_match;
+static unsigned int max_lazy_match;
 /* Attempt to find a better match only when the current match is strictly
  * smaller than this value. This mechanism is used only for compression
  * levels >= 4.
@@ -215,14 +211,11 @@ local unsigned int max_lazy_match;
  * max_insert_length is used only for compression levels <= 3.
  */
 
-local int compr_level;
-/* compression level (1..9) */
-
 unsigned good_match;
 /* Use a faster search when the previous match is longer than this */
 
-local ulg rsync_sum;  /* rolling sum of rsync window */
-local ulg rsync_chunk_end; /* next rsync sequence point */
+static ulg rsync_sum;  /* rolling sum of rsync window */
+static ulg rsync_chunk_end; /* next rsync sequence point */
 
 /* Values for max_lazy_match, good_match and max_chain_length, depending on
  * the desired pack level (0..9). The values given below have been tuned to
@@ -250,7 +243,7 @@ typedef struct config {
   static_unless_ASMV int nice_match;
 #endif
 
-local config configuration_table[10] = {
+static config configuration_table[10] = {
 /*      good lazy nice chain */
 /* 0 */ {0,    0,  0,    0},  /* store only */
 /* 1 */ {4,    4,  8,    4},  /* maximum speed, no lazy matches */
@@ -272,8 +265,8 @@ local config configuration_table[10] = {
 /* ===========================================================================
  *  Prototypes for local functions.
  */
-local void fill_window   (void);
-local off_t deflate_fast (void);
+static void fill_window (void);
+static off_t deflate_fast (void);
 
 #ifdef ASMV
       int  longest_match (IPos cur_match);
@@ -281,7 +274,7 @@ local off_t deflate_fast (void);
 #endif
 
 #ifdef DEBUG
-local  void check_match (IPos start, IPos match, int length);
+static void check_match (IPos start, IPos match, int length);
 #endif
 
 /* ===========================================================================
@@ -307,15 +300,14 @@ local  void check_match (IPos start, IPos match, int length);
 
 /* ===========================================================================
  * Initialize the "longest match" routines for a new file
+ * PACK_LEVEL values: 0: store, 1: best speed, 9: best compression
  */
-void lm_init (pack_level, flags)
-    int pack_level; /* 0: store, 1: best speed, 9: best compression */
-    ush *flags;     /* general purpose bit flag */
+static void
+lm_init (int pack_level)
 {
     register unsigned j;
 
     if (pack_level < 1 || pack_level > 9) gzip_error ("bad pack level");
-    compr_level = pack_level;
 
     /* Initialize the hash table. */
 #if defined MAXSEG_64K && HASH_BITS == 15
@@ -337,11 +329,6 @@ void lm_init (pack_level, flags)
     nice_match       = configuration_table[pack_level].nice_length;
 #endif
     max_chain_length = configuration_table[pack_level].max_chain;
-    if (pack_level == 1) {
-       *flags |= FAST;
-    } else if (pack_level == 9) {
-       *flags |= SLOW;
-    }
     /* ??? reduce max_chain_length for binary files */
 
     strstart = 0;
@@ -513,20 +500,19 @@ longest_match(IPos cur_match)
 /* ===========================================================================
  * Check that the match at match_start is indeed a match.
  */
-local void check_match(start, match, length)
-    IPos start, match;
-    int length;
+static void
+check_match (IPos start, IPos match, int length)
 {
     /* check that the match is indeed a match */
     if (memcmp((char*)window + match,
                 (char*)window + start, length) != 0) {
         fprintf(stderr,
-            " start %d, match %d, length %d\n",
+            " start %u, match %u, length %d\n",
             start, match, length);
         gzip_error ("invalid match");
     }
     if (verbose > 1) {
-        fprintf(stderr,"\\[%d,%d]", start-match, length);
+        fprintf (stderr, "\\[%u,%d]", start - match, length);
         do { putc(window[start++], stderr); } while (--length != 0);
     }
 }
@@ -542,7 +528,8 @@ local void check_match(start, match, length)
  *    file reads are performed for at least two bytes (required for the
  *    translate_eol option).
  */
-local void fill_window()
+static void
+fill_window ()
 {
     register unsigned n, m;
     unsigned more = (unsigned)(window_size - (ulg)lookahead - (ulg)strstart);
@@ -598,7 +585,8 @@ local void fill_window()
 
 /* With an initial offset of START, advance rsync's rolling checksum
    by NUM bytes.  */
-local void rsync_roll(unsigned int start, unsigned int num)
+static void
+rsync_roll (unsigned int start, unsigned int num)
 {
     unsigned i;
 
@@ -644,7 +632,8 @@ local void rsync_roll(unsigned int start, unsigned int num)
  * new strings in the dictionary only for unmatched strings or for short
  * matches. It is used only for the fast compression options.
  */
-local off_t deflate_fast()
+static off_t
+deflate_fast ()
 {
     IPos hash_head; /* head of the hash chain */
     int flush = 0;  /* set if current block must be flushed, 2=>and padded  */
@@ -732,7 +721,8 @@ local off_t deflate_fast()
  * evaluation for matches: a match is finally adopted only if there is
  * no better match at the next window position.
  */
-off_t deflate()
+off_t
+deflate (int pack_level)
 {
     IPos hash_head;          /* head of hash chain */
     IPos prev_match;         /* previous match */
@@ -740,7 +730,9 @@ off_t deflate()
     int match_available = 0; /* set if previous match exists */
     register unsigned match_length = MIN_MATCH-1; /* length of best match */
 
-    if (compr_level <= 3) return deflate_fast(); /* optimized for speed */
+    lm_init (pack_level);
+    if (pack_level <= 3)
+      return deflate_fast();
 
     /* Process the input block. */
     while (lookahead != 0) {
